
Installation
============

Installation is easy using ``pip`` or ``easy_install``.

.. code-block:: bash

	pip install {{pkg_name}}

or

.. code-block:: bash

	easy_install {{pkg_name}}

Dependencies
************
